@@ -1,5 +1,5 @@
 """Augment pandas DataFrame with methods for quant analysis"""
-__version__ = '0.1.9'
+__version__ = '0.1.10'
 
 import importlib
 import sys as _sys
@@ -16,14 +16,15 @@ _log.debug(f"pandas version {pd.__version__}")
 setattr(PandasObject, "ta", property(lambda self: _TA(self)))
 
 # auto import pandas ml utils
-if 'pandas_ml_utils' in _sys.modules:
+try:
     pandas_ml_utils = importlib.import_module("pandas_ml_utils")
+except:
     _log.warning(f"automatically imported pandas_ml_utils {pandas_ml_utils.__version__}")
 
 # auto import pandas ml quant data prviders
-if 'pandas_ml_quant_data_provider' in _sys.modules:
+try:
     pandas_ml_quant_data_provider = importlib.import_module("pandas_ml_quant_data_provider")
     _log.warning(f"automatically imported pandas_ml_quant_data_provider {pandas_ml_quant_data_provider.__version__}")
-else:
+except:
     _log.warning("pandas_ml_quant_data_provider module not avialable!")
 
